Subject: Re: [sup-talk] [PATCH] If we have a COLUMNS environment variable, wrap to that instead of 80.

From: Anthony Martinez <[email-masked]>
Date: Tue, 03 Nov 2009 20:22:24 -0700

Excerpts from Anthony Martinez's message of Tue Nov 03 20:05:19 -0700 2009:
> I find that this provides a much smoother terminal experience,
Or it would if I tested it. Sorry about the bad patch, seems today isn't my day.
:)

Either way, I'd like to see something like this. Discussion?
_______________________________________________
sup-talk mailing list
[email-masked]
http://rubyforge.org/mailman/listinfo/sup-talk

---

From: Anthony Martinez <[email-masked]>
Date: Tue, 03 Nov 2009 20:51:46 -0700

I find that this provides a much smoother terminal experience,
especially with elinks configured to dump to the same size in hook
scripts.

At least on Linux, "stty size"'s second numerical output is the number
of columns, and if that fails somehow, sup will continue to happily
default to 80.
---
 lib/sup/message-chunks.rb |    3 ++-
 1 files changed, 2 insertions(+), 1 deletions(-)

diff --git a/lib/sup/message-chunks.rb b/lib/sup/message-chunks.rb
index 581b707..881ac4b 100644
--- a/lib/sup/message-chunks.rb
+++ b/lib/sup/message-chunks.rb
@@ -41,7 +41,7 @@ end
 
 module Redwood
 module Chunk
 
   class Attachment
diff --git a/lib/sup/message-chunks.rb b/lib/sup/message-chunks.rb
index 581b707..56ddf1e 100644
--- a/lib/sup/message-chunks.rb
+++ b/lib/sup/message-chunks.rb
@@ -41,7 +41,8 @@ end

 module Redwood
 module Chunk
-  WRAP_LEN = 80 # wrap messages and text attachments at this width
+  TERM_WIDTH = `stty size 2>/dev/null`.split[1].to_i # to_i returns 0 if it fails.
+  WRAP_LEN = TERM_WIDTH > 0 && TERM_WIDTH || 80 # wrap messages and text attachments at this width

   class Attachment
     HookManager.register "mime-decode", <<EOS
_______________________________________________
sup-talk mailing list
[email-masked]
http://rubyforge.org/mailman/listinfo/sup-talk

---

From: Mark Alexander <[email-masked]>
Date: Wed, 04 Nov 2009 14:06:01 -0500

Excerpts from Anthony Martinez's message of Tue Nov 03 22:05:19 -0500 2009:
> +  WRAP_LEN = ENV["COLUMNS"] || 80 # wrap messages and text attachments at this width

How about using Ncurses.cols?  That's what I did in a similar patch on
my copy of sup.
_______________________________________________
sup-talk mailing list
[email-masked]
http://rubyforge.org/mailman/listinfo/sup-talk

---

From: Anthony Martinez <[email-masked]>
Date: Tue, 3 Nov 2009 20:05:19 -0700

From: Anthony Martinez <[email-masked]>

I find that this provides a much smoother terminal experience,
especially with dumped HTML output. At least on Linux+zsh, this
environment variable is automatically updated, and if it doesn't exist,
sup will continue to happily default to 80.
---
 lib/sup/message-chunks.rb |    2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)

-- 
1.6.5